<?php
/**
 * Plugin Name: Dellin shipping for WooCommerce
 * Description: The plugin allows you to automatically calculate shipping costs using dellin.ru API service.
 * Version: 1.1.0
 * Author: Деловые Линии
 * Text Domain: dellin-shipping-for-woocommerce
 * Domain Path: /languages
 * WC requires at least: 3.6.0
 * WC tested up to: 4.3.0
 *
 * @package Dellin shipping
 */

defined( 'ABSPATH' ) || exit;


// Define DELLIN_PLUGIN_DIR.
if ( ! defined( 'DELLIN_PLUGIN_DIR' ) ) {
    define( 'DELLIN_PLUGIN_DIR', str_replace( '\\', '/', dirname( __FILE__ ) ));
}

//include(DELLIN_PLUGIN_DIR."/inc/class-dellin-shipping-method.php");
//include('../woocommerce/includes/abstracts/abstract-wc-shipping-method.php');
//new WC_Shipping_Method();
//new Dellin_Shipping_Method();



/**
 *
 * Dellin Main Class
 *
 */
class DellinShipping {

    /**
     * Constructor.
     */

    public function __construct() {
        // apply plugin textdomain.

        add_action( 'plugins_loaded', array( $this, 'load_textdomain' ) );

        // add new shipping method.
        add_action( 'woocommerce_shipping_init', array( $this, 'init_method' ) );
        add_filter( 'woocommerce_shipping_methods', array( $this, 'register_method' ) );

        add_filter( 'auto_update_plugin', array( $this, 'auto_update_plugin' ), 10, 2 );
        //add meta block for request
        add_action( 'add_meta_boxes', array($this, 'registerMetaBox'));
//	    add_filter( 'woocommerce_checkout_fields' , 'custom_checkout_fields' );

//      add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), array( $this, 'plugin_action_links' ) );//TODO - добавить инструкцию по настройке при её наличии

	    add_filter( 'woocommerce_ship_to_different_address_checked', '__return_true' );
        add_action('woocommerce_view_order', array($this, 'check_shipping_status'));

        $this->init();
    }



    public function check_shipping_status($order_id){

        $order = wc_get_order($order_id);
        $orderData = $order->get_data();

        $shipping_method = '';
        $instance_id = '';
        foreach( $order->get_items( 'shipping' ) as $item_id => $shipping_item_obj ) {
            $shipping_method = $shipping_item_obj->get_method_id();
            $instance_id = $shipping_item_obj->get_instance_id();
        }

        if($shipping_method == 'dellin_shipping_calc'){
            $config = DellinApi::getConfig($instance_id);
            $user_id = $order->get_data()["customer_id"];
            $terminalID = get_user_meta( $user_id, 'terminal_id', true );
            $typeShipping = ($config["is_goods_unloading"] != 'no') ? 'adr' : 'term';
            $terminal = ApiCore::GetTerminals($config['appkey'], true, $terminalID);
            $fullAddress = ($typeShipping == 'term')? $terminal['terminal']->fullAddress : $order->get_formatted_shipping_address();
            $trackId = get_post_meta( $order_id, '_dellin_track_id', true );
            $trackData = DellinApi::GetOrderStatus($trackId, $instance_id);
            $trackStatus = ($trackId !== '')? $trackData->state_name : false;

            include_once dirname( __FILE__ ).'/inc/view/my-order-dellin-status.php';



        }

    }

    /**
     * Load textdomain for a plugin
     */
    public function load_textdomain() {
        load_plugin_textdomain( 'dellin-shipping-for-woocommerce', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
    }

    /**
     * Add shipping method
     */
    public function init_method() {
        if ( ! class_exists( 'Dellin_Shipping_Method' ) ) {
            include_once dirname( __FILE__ ) . '/inc/class-dellin-shipping-method.php';
        }
    }


    /**
     * Register shipping method
     *
     * @param array $methods Shipping methods.
     *
     * @return array
     */
    public function register_method( $methods ) {
        $methods['dellin_shipping_calc'] = 'Dellin_Shipping_Method';

        return $methods;
    }


    /**
     * Auto update plugin
     *
     * @param bool   $should_update If should update.
     * @param object $plugin Plugin data.
     *
     * @return bool
     */
    public function auto_update_plugin( $should_update, $plugin ) {
        if ( 'dellin-shipping-for-woocommerce/dellin-shipping-for-woocommerce.php' === $plugin->plugin ) {
            return true;
        }

        return $should_update;
    }


    /**
     * Display helpful links
     *
     * @param array $links Key - link pair.
     *
     * @return array
     */

     //TODO - добавить инструкцию по настройке при её наличии
     /*
    public function plugin_action_links( $links ) {
        $settings = array( 'settings' => '<a href="' . admin_url( 'admin.php?page=wc-settings&tab=shipping&section=dellinshipping' ) . '">' . __( 'Settings', 'dellin-shipping-for-woocommerce' ) . '</a>' );
        $links = $settings + $links;
        return $links;
    }
    */
    /**
     * Plugin dir url helper
     *
     * @return string
     */
    public static function plugin_dir_url() {
        return plugin_dir_url( __FILE__ );
    }

    /**
     * Method for action register metabox
     */

    function registerMetaBox() {
        global $post;
        $id = $post->ID;
        if(isset($_GET['post']) && $_GET['post'] == $id && (isset($_GET['action']) && $_GET['action'] == 'edit') ){


            $order = wc_get_order( $post->ID );

            if($order){
                $shipping_method = @array_shift($order->get_shipping_methods());
                $shipping_method_id = $shipping_method['method_id'];
                if($shipping_method_id == 'dellin_shipping_calc'){
                    add_meta_box(
                        'order_data',
                        esc_html__( 'Доставка деловые линии', 'text-domain' ),
                        array($this, 'renderMetaBox'),
                        'shop_order', // shop_order is the post type of the admin order page
                        'normal', // change to 'side' to move box to side column 
                        'low' // priority (where on page to put the box)
                    );
                    $v = '0.02';//версия
                    wp_localize_script('jquery', 'dellinVars',
                        array(
                            'url' => admin_url('admin-ajax.php'),
                            'postId' => $id
                        ));
                        
                    wp_register_script('dellinDeliverySettingsScript', DellinShipping::plugin_dir_url() . '/../assets/js/dellinDeliveryRequest.js', array('jquery'), $v);
                    wp_enqueue_script('dellinDeliverySettingsScript');

                    // add meta field for trackId and status
                    add_action('woocommerce_checkout_update_order_meta', array($this,'dellinShippingTrackId'));
                    // Save and display custom fields in order item meta
 //                   add_action( 'woocommerce_add_order_item_meta', 'addCustomFieldsOrderItemMeta', 20, 3 );
//                    update_post_meta( $post->ID, '_dellin_track_id', 'None', '' );
//                    update_post_meta($post->ID, '_dellin_status_track', 'None', '' );
                    
                    wp_register_style('dellinDeliverySettingsStyle', DellinShipping::plugin_dir_url() . 'assets/css/dellinDeliveryRequest.css', array(), $v);
                    wp_enqueue_style('dellinDeliverySettingsStyle');
                   
                }
            }
        }
    }
    
    /**
     * Method get DOM block in metabox.
     * Using for RequestV2.
     */
    public static function renderMetaBox() {
        global $post;
        $order = wc_get_order($post->ID);
	    $trackId = get_post_meta( $post->ID, '_dellin_track_id', true );
        $shipping_method = @array_shift($order->get_shipping_methods());
        $instance_id = $shipping_method['instance_id'];

        if($trackId == ''){
	        // Если запрос делается впервые.
	        DellinShipping_Admin::createModal();
        } else {

	        //
	        $trackData = DellinApi::GetOrderStatus($trackId, $instance_id);
	        $trackStatus = $trackData->state_name;
	        DellinShipping_Admin::dellinRenderTableStatus($trackId, $trackStatus);
        }
    }



    /**
     * Add plugin partials
     */
    public function init() {
        include_once dirname( __FILE__ ) . '/inc/class-dellin-shipping-admin.php';
	    include_once dirname( __FILE__ ) . '/inc/class-dellin-shipping-fields.php';
        new DellinShipping_Admin();
        new Dellin_Fields();
    }
}
// Init plugin if woo is active.
if ( in_array(
    'woocommerce/woocommerce.php',
    apply_filters( 'active_plugins', get_option( 'active_plugins' ) ),
    true
) ) {
    new DellinShipping();
}

?>