<?php

defined( 'ABSPATH' ) || exit;

class Dellin_Fields
{

	public function __construct (){
		// кастомные значения для юриков
		add_action( 'woocommerce_before_checkout_billing_form', array($this, 'organisation_checkout_field'));
		add_action( 'woocommerce_before_edit_account_form', array($this, 'organisation_checkout_field'));
		add_action( 'woocommerce_checkout_process', array($this, 'my_custom_checkout_field_process'));
		add_action( 'woocommerce_checkout_update_order_meta', array($this,  'my_custom_checkout_field_update_order_meta'));
		add_action( 'woocommerce_order_details_after_customer_details', array($this, 'organisation_checkout_field_echo_in_order'));
		add_action( 'woocommerce_insert_organisation_details',  array($this, 'organisation_checkout_field_echo_in_order'));
		add_action( 'woocommerce_admin_order_data_after_shipping_address', array($this, 'organisation_checkout_field_echo_in_admin_order' ), 10 );
		add_action( 'wp_footer',  array($this, 'terminalFields'));
        add_action( 'woocommerce_after_checkout_form', array($this,'terminalFields') );
//		add_filter( 'woocommerce_checkout_fields', array($this, 'add_filter_in_checkout_custom_field'), 1);
        add_action('woocommerce_calculated_shipping', array($this, 'change_calc_method'));
        add_action( 'woocommerce_after_shipping_rate', array( $this, 'add_terminals' ), 10, 2 );
	}


    /**
     * @param $instance_id
     *
     * @return bool
     */

    public function is_shipping_terminal($instance_id){
        $config = DellinApi::getConfig($instance_id);
        $result = false;
        if($config['is_goods_unloading'] == 'no'){
            $result =  true;
        }
        return $result;
    }

    /**
     * @param $teminals_in_session
     * @return array
     */

	function getValidTerminals($teminals_in_session){
	    $options = [];

	    foreach ($teminals_in_session as $key => $value){

	        $options += [$value->id => $value->address];

        }

	    return $options;
    }





	function add_terminals($method){


        if($this->is_shipping_terminal($method->instance_id) && is_checkout()){
            woocommerce_form_field('terminal_id' , array(
                'title'       => __( 'departure terminal', 'dellin-shipping-for-woocommerce' ),
                'description' => __( 'Select departure terminal', 'dellin-shipping-for-woocommerce'),
                'type'        => 'select',
                'default'     => '',
                'options'     => $this->getValidTerminals($_SESSION['current_terminals']),
            ));
        }
    }



    /**
     * Переопределяем метод просчёта стоимости.
     * Метод находится в шорткоде class-wc-shortcode-cart.php.
     *
     */
	function change_calc_method(){

	    try {

        WC()->shipping()->reset_shipping();

	    $address = array();

        $address['country']  = isset( $_POST['calc_shipping_country'] ) ? wc_clean( wp_unslash( $_POST['calc_shipping_country'] ) ) : ''; // WPCS: input var ok, CSRF ok, sanitization ok.
        $address['state']    = isset( $_POST['calc_shipping_state'] ) ? wc_clean( wp_unslash( $_POST['calc_shipping_state'] ) ) : ''; // WPCS: input var ok, CSRF ok, sanitization ok.
        $address['postcode'] = isset( $_POST['calc_shipping_postcode'] ) ? wc_clean( wp_unslash( $_POST['calc_shipping_postcode'] ) ) : ''; // WPCS: input var ok, CSRF ok, sanitization ok.
        $address['city']     = isset( $_POST['calc_shipping_city'] ) ? wc_clean( wp_unslash( $_POST['calc_shipping_city'] ) ) : ''; // WPCS: input var ok, CSRF ok, sanitization ok.
        $address['address_1'] = isset($_POST['calc_shipping_address']) ? wc_clean( wp_unslash($_POST['calc_shipping_address'])) : ''; // WPCS: input var ok, CSRF ok, sanitization ok.
        $address['terminal_id'] = isset($_POST['terminal_id']) ? wc_clean( wp_unslash($_POST['terminal_id'])) : '';


        $address = apply_filters( 'woocommerce_cart_calculate_shipping_address', $address );


        $current_user = wp_get_current_user();
        $user_id = $current_user->ID;

        if($address['terminal_id'] !== ''){
            update_user_meta( $user_id,
                'terminal_id',
                sanitize_text_field( $_POST['terminal_id'])
            );
        }

        if ( $address['postcode'] && ! WC_Validation::is_postcode( $address['postcode'], $address['country'] ) ) {
            throw new Exception( __( 'Please enter a valid postcode / ZIP.', 'woocommerce' ) );
        } elseif ( $address['postcode'] ) {
            $address['postcode'] = wc_format_postcode( $address['postcode'], $address['country'] );
        }

        if ( $address['country'] ) {
            if ( ! WC()->customer->get_billing_first_name() ) {
                WC()->customer->set_props('billing', $address );
                WC()->customer->set_billing_address($address['address_1']);
            }
            WC()->customer->set_props('shipping', $address);
            WC()->customer->set_shipping_address($address['address_1']);
        } else {
            WC()->customer->set_props('billing', $address );
            WC()->customer->set_props('shipping', $address);
        }

        $woocommerce_ship_to_destination = get_option('woocommerce_ship_to_destination');

        if($woocommerce_ship_to_destination == 'billing_only'){
            WC()->customer->set_billing_country($address['country']);
            WC()->customer->set_billing_state($address['state']);
            WC()->customer->set_billing_city($address['city']);
            WC()->customer->set_billing_address($address['address_1']);
        }



        WC()->customer->set_calculated_shipping( true );

        WC()->customer->save();



        wc_add_notice( __( 'Shipping costs updated.', 'woocommerce' ), 'notice' );



        } catch ( Exception $e ) {
            if ( ! empty( $e ) ) {
                wc_add_notice( $e->getMessage(), 'error' );
            }
        }


    }

//	function add_filter_in_checkout_custom_field( $fields )
//    {
//        $woocommerce_ship_to_destination = get_option('woocommerce_ship_to_destination');
//
//        if ( $woocommerce_ship_to_destination == 'billing_only' ||
//            $woocommerce_ship_to_destination == 'billing') {
//        $fields['billing']['terminal_id'] = array(
//            'label' => 'Адрес терминала:',
//            'title' => __('Терминал доставки', 'dellin-shipping-for-woocommerce'),
//            'type' => 'select',
//            'options' => array('' => 'Терминал не выбран'),
//            'class' => array('my-field-class form-row-wide'),
//            'validate' => array('terminal_id'),
//            'required' => true,
//
//        );
//        } else {
//            $fields['shipping']['terminal_id'] = array(
//                'label' => 'Адрес терминала:',
//                'title' => __('Терминал доставки', 'dellin-shipping-for-woocommerce'),
//                'type' => 'select',
//                'options' => array('' => 'Терминал не выбран'),
//                'class' => array('my-field-class form-row-wide'),
//                'validate' => array('terminal_id'),
//                'required' => true
//            );
//        }
//
////        $fields['billing']['billing_first_name']['priority'] = 1;
////        $fields['billing']['billing_last_name']['priority'] = 2;
////        $fields['billing']['billing_country']['priority'] = 3;
////        $fields['billing']['billing_state']['priority'] = 4;
////        $fields['billing']['billing_city']['priority'] = 5;
////        $fields['billing']['billing_address_1']['priority'] = 7;
////  //      $fields['billing']['terminal_id']['priority'] = 8;
////        $fields['billing']['billing_postcode']['priority'] = 9;
////        $fields['billing']['billing_email']['priority'] = 10;
////        $fields['billing']['billing_phone']['priority'] = 11;
//
//
//        return $fields;
//
//    }




	function terminalFields(){
		if (is_checkout()){

			$current_user = wp_get_current_user();
			$user_id = $current_user->ID;
			$nonce = wp_create_nonce('dellin-terminal');


			?>
			<script type="text/javascript">
                jQuery(function($) {

                    var doGetRequest = function(terminal_id, user_id){
                        return jQuery.ajax({
                            url: wc_add_to_cart_params.ajax_url,
                            data: {'ajax':'y',
                                'action':'set_terminal_in_cart',
                                'security': '<?php echo $nonce ?>' ,
                                'terminal_id':terminal_id, 'id': user_id},
                            method: "POST",
                            dataType: "json"
                        }).done(function(response){
                            var select = jQuery('#terminal_id');
                            if(undefined != response['error'] && jQuery(select).closest('tr').find('.error').length == 0){
                                $(document.body).trigger('update_checkout');
                                    window.location.reload();
                            }
                        });
                    }

                    $('#terminal_id').on('change', function () {

                        var terminal_id = $('#terminal_id > option:selected').val();
                            console.log($('#terminal_id > option:selected').val())
                            doGetRequest(terminal_id, <?php echo $user_id ?>)
                        $(document.body).trigger('update_checkout');

                    })

                    // $(document.body).trigger('update_checkout');
                    // console.log('Event: update_checkout');

                });
			</script>
			<?php
		}
	}



	/**
	 * Параметры для физических и юридических лиц.
	 * @param $checkout
	 */


	function organisation_checkout_field( $checkout ) {
		//

		$current_user = wp_get_current_user();
		$user_id = $current_user->ID;




		echo '<div id="organisation_checkout_field">';
		woocommerce_form_field( 'organisation', array(
			'type'    => 'radio',
			'class'   => array('form-row-wide'),
			'label'   =>  '',
			'options' => array(
				'private_person' => 'Частное лицо',
				'company' => 'Организация'
			)
		), $checkout->get_value( 'organisation' ));
		echo '</div>';


		?>
		<script>
            jQuery(function() {
                var $radios = jQuery('input:radio[name=organisation]');
                if($radios.is(':checked') === false) {
                    $radios.filter('[value="private_person"]').prop('checked', true);
                }
            });

            // Скрытие реквизитов
            jQuery(document).ready(function($){


                $('.woocommerce-organisation-fields__field-wrapper').hide();

                $("input[name=organisation]:radio").click(function () {
                    if ($('input[name=organisation]:checked').val() == "private_person") {
                        $('.woocommerce-organisation-fields__field-wrapper').hide();
                    } else if ($('input[name=organisation]:checked').val() == "company") {
                        $('.woocommerce-organisation-fields__field-wrapper').show();
                    }
                });
            });
		</script>
		<?php

		echo '<div class="woocommerce-organisation-fields__field-wrapper"><h3>Реквизиты организации</h3>';

		woocommerce_form_field( 'organisation_name', array(
			'required'      => true,
			'type'          => 'text',
			'class'         => array('my-field-class form-row-wide'),
			'placeholder'   => __('Наименование'),
		), get_user_meta( $user_id, 'organisation_name', true ));

		woocommerce_form_field( 'organisation_address', array(
			'required'      => true,
			'type'          => 'text',
			'class'         => array('my-field-class form-row-wide'),
			'placeholder'   => __('Адрес организации'),
		), get_user_meta( $user_id, 'organisation_address', true ));

		woocommerce_form_field( 'organisation_inn', array(
			'required'      => true,
			'type'          => 'text',
			'class'         => array('my-field-class form-row-wide'),
			'placeholder'   => __('ИНН'),
		), get_user_meta( $user_id, 'organisation_inn', true ));



		echo '</div>';
	}



	function my_custom_checkout_field_process() {
		$radioVal = $_POST["organisation"];

		if($radioVal == "company") {
			if ( ! $_POST['organisation_name'] ) wc_add_notice( __( '<strong>Наименование организации</strong> является обязательным полем.' ), 'error' );
			if ( ! $_POST['organisation_address'] ) wc_add_notice( __( '<strong>Адрес организации</strong> является обязательным полем.' ), 'error' );
			if ( ! $_POST['organisation_inn'] ) wc_add_notice( __( '<strong>ИНН</strong> является обязательным полем.' ), 'error' );

		}
   //     if ( ! $_POST['terminal_id'] ) wc_add_notice( __( '<strong>Адресс терминала</strong> является обязательным полем.' ), 'error' );
      
	}



	function my_custom_checkout_field_update_order_meta() {
		$current_user = wp_get_current_user();
		$user_id = $current_user->ID;

		$radioVal = $_POST["organisation"];
		if($radioVal == "company") { update_user_meta( $user_id, 'company', 'on' ); } else { delete_user_meta( $user_id, 'company' ); }

		if ( ! empty( $_POST['organisation_name'] ) ) { update_user_meta( $user_id, 'organisation_name', sanitize_text_field( $_POST['organisation_name'] ) ); }
		if ( ! empty( $_POST['organisation_address'] ) ) { update_user_meta( $user_id, 'organisation_address', sanitize_text_field( $_POST['organisation_address'] ) ); }
		if ( ! empty( $_POST['organisation_inn'] ) ) { update_user_meta( $user_id, 'organisation_inn', sanitize_text_field( $_POST['organisation_inn'] ) ); }
        if ( ! empty( $_POST['terminal_id'] ) ) { update_user_meta( $user_id, 'terminal_id', sanitize_text_field( $_POST['terminal_id'] ) ); }
	}


	function organisation_checkout_field_echo_in_order() {
		$current_user = wp_get_current_user();
		$user_id = $current_user->ID;
		$user_id_company = get_user_meta( $user_id, 'company', 'on' );
		//	var_dump($user_id_company);
		if($user_id_company) {
			echo '<h2>Реквизиты компании</h2>';
			echo 'Наименование: '. get_user_meta( $user_id, 'organisation_name', true ).'<br>';
			echo 'Адрес: '.get_user_meta( $user_id, 'organisation_address', true ).'<br>';
			echo 'ИНН: '.get_user_meta( $user_id, 'organisation_inn', true ).'<br>';
		}
	}


	function organisation_checkout_field_echo_in_admin_order() {
		global $post;
		$order = wc_get_order($post->ID);
		$dataOrder = $order->get_data();
		$user_id = $dataOrder['customer_id'];
		$user_id_company = get_user_meta( $user_id, 'company', 'on' );
		if($user_id_company) {
			echo '</div></div><div class="clear"></div>';
			echo '<div class="order_data_column_container"><div class="order_data_column_wide">';
			echo '<h3>Реквизиты компании</h3>';
			echo 'Наименование: '.get_user_meta( $user_id, 'organisation_name', true ).'<br>';
			echo 'Адрес: '.get_user_meta( $user_id, 'organisation_address', true ).'<br>';
			echo 'ИНН: '.get_user_meta( $user_id, 'organisation_inn', true ).'<br>';
		}
	}


}


